@@ -12,15 +12,11 @@ test_that("read_conservation_units", {
 
   # read data
   test_sf <- read_conservation_units(date=201909)
-  expect_output(read_conservation_units(date=NULL))
+  testthat::expect_output(read_conservation_units())
 
 
   # check sf object
-  expect_true(is(test_sf, "sf"))
-
-
-  # check projection
-    expect_equal(sf::st_crs(test_sf)[[2]], "+proj=longlat +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +no_defs")
+  testthat::expect_true(is(test_sf, "sf"))
 
 })
 
@@ -30,7 +26,8 @@ test_that("read_conservation_units", {
 test_that("read_conservation_units", {
 
   # Wrong date
-  expect_error(read_conservation_units(date=9999999))
-  expect_error(read_conservation_units(date="xxx"))
+  testthat::expect_error(read_conservation_units(date=9999999))
+  testthat::expect_error(read_conservation_units(date="xxx"))
+  testthat::expect_error(read_conservation_units(tp="xxx"))
 
 })
