@@ -7,23 +7,6 @@ testthat::skip_on_cran()
 
 
 
-
-# Downloading the data -----------------------
-
-test_that("read_disaster_risk_area", {
-
-  # read data
-  test_sf <- read_disaster_risk_area(year=2010)
-    # test
-    expect_equal(test_sf %>% length(), 10)
-
-}
-)
-
-
-
-
-
 # Reading the data -----------------------
 
 test_that("read_disaster_risk_area", {
@@ -33,13 +16,10 @@ test_that("read_disaster_risk_area", {
   test_sf <- read_disaster_risk_area(year=2010)
 
   # check sf object
-  expect_true(is(test_sf, "sf"))
+  testthat::expect_true(is(test_sf, "sf"))
 
   # check number of micro
-  expect_equal(test_sf$geo_bater %>% length(), 8309)
-
-  # check projection
-  expect_equal(sf::st_crs(test_sf)[[2]], "+proj=longlat +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +no_defs")
+  testthat::expect_equal(test_sf$geo_bater %>% length(), 8309)
 
 })
 
@@ -50,8 +30,8 @@ test_that("read_disaster_risk_area", {
 test_that("read_disaster_risk_area", {
 
   # Wrong year
-  expect_error(read_disaster_risk_area(year=9999999))
-  expect_error(read_disaster_risk_area(year="xxx"))
-  expect_error(read_disaster_risk_area(year=NULL))
+  testthat::expect_error(read_disaster_risk_area(year=9999999))
+  testthat::expect_error(read_disaster_risk_area(year="xxx"))
+  testthat::expect_error(read_disaster_risk_area(year=NULL))
 
 })
