@@ -10,12 +10,11 @@ testthat::skip_on_cran()
 test_that("read_municipal_seat", {
 
   # read data and check sf object
-  expect_true(is(read_municipal_seat(year=NULL), "sf"))
+  testthat::expect_output( read_municipal_seat() )
   test_sf <- read_municipal_seat(year=1991)
-  expect_true(is(test_sf, "sf"))
 
-  # check projection
-    expect_equal(sf::st_crs(test_sf)[[2]], "+proj=longlat +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +no_defs")
+
+  expect_true(is(test_sf, "sf"))
 
 })
 
